@@ -17,10 +17,10 @@
 #' @param ... other parameters
 #' @param label label that will be passed into \code{\link[DALEX]{explain}}. If NULL, default will be used.
 #' @param verbose bool that will be passed into \code{\link[DALEX]{explain}}. If NULL, default will be used.
-#' @param precalculate if TRUE (default) then 'predicted_values' and 'residuals' are calculated when explainer is created. This will happenn also if 'verbose' is TRUE.
+#' @param precalculate if TRUE (default) then 'predicted_values' and 'residuals' are calculated when explainer is created.
 #' @param colorize if TRUE (default) then \code{WARNINGS}, \code{ERRORS} and \code{NOTES} are colorized. Will work only in the R console.
 #' @param model_info a named list (\code{package}, \code{version}, \code{type}) containg information about model. If \code{NULL}, \code{DALEX} will seek for information on it's own.
-#'
+#' @param type type of a model, either \code{classification} or \code{regression}. If not specified then \code{type} will be extracted from \code{model_info}.
 #'
 #' @author Szymon Maksymiuk
 #'
@@ -95,7 +95,8 @@ explain_keras <-
            verbose = TRUE,
            precalculate = TRUE,
            colorize = TRUE,
-           model_info = NULL) {
+           model_info = NULL,
+           type = NULL) {
 
     prepeare_env(yml, condaenv, env)
 
@@ -113,6 +114,7 @@ explain_keras <-
       verbose = verbose,
       precalculate = precalculate,
       colorize = colorize,
-      model_info = model_info
+      model_info = model_info,
+      type = type
     )
   }
