@@ -17,9 +17,10 @@
 #' @param ... other parameters
 #' @param label label that will be passed into \code{\link[DALEX]{explain}}. If NULL, default will be used.
 #' @param verbose bool that will be passed into \code{\link[DALEX]{explain}}. If NULL, default will be used.
-#' @param precalculate if TRUE (default) then 'predicted_values' and 'residuals' are calculated when explainer is created. This will happenn also if 'verbose' is TRUE.
+#' @param precalculate if TRUE (default) then 'predicted_values' and 'residuals' are calculated when explainer is created.
 #' @param colorize if TRUE (default) then \code{WARNINGS}, \code{ERRORS} and \code{NOTES} are colorized. Will work only in the R console.
 #' @param model_info a named list (\code{package}, \code{version}, \code{type}) containg information about model. If \code{NULL}, \code{DALEX} will seek for information on it's own.
+#' @param type type of a model, either \code{classification} or \code{regression}. If not specified then \code{type} will be extracted from \code{model_info}.
 #'
 #'
 #' @author Szymon Maksymiuk
@@ -72,8 +73,7 @@
 #' @importFrom utils head
 #'
 #' @examples
-#' library("DALEXtra")
-#' if(DALEXtra:::is_conda()) {
+#' \donttest{
 #'    # Explainer build (Keep in mind that 18th column is target)
 #'    titanic_test <- read.csv(system.file("extdata", "titanic_test.csv", package = "DALEXtra"))
 #'    # Keep in mind that when pickle is being built and loaded,
@@ -86,8 +86,6 @@
 #'    # Predictions with newdata
 #'    predict(explainer, titanic_test[1:10,1:17])
 #'
-#' } else {
-#'   print('Conda is required.')
 #' }
 #'
 #' @rdname explain_scikitlearn
@@ -108,7 +106,8 @@ explain_scikitlearn <-
            verbose = TRUE,
            precalculate = TRUE,
            colorize = TRUE,
-           model_info = NULL) {
+           model_info = NULL,
+           type = NULL) {
     prepeare_env(yml, condaenv, env)
 
     model <- dalex_load_object(path, "scikitlearn_model")
@@ -163,7 +162,8 @@ explain_scikitlearn <-
                           verbose = verbose,
                           precalculate = precalculate,
                           colorize = colorize,
-                          model_info = model_info
+                          model_info = model_info,
+                          type = type
                         )
     explainer$param_set <- params
     explainer
